@@ -191,7 +191,7 @@ main (gint argc, gchar **argv)
     xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
     /* initialize Gtk+ */
-    if(!gtk_init_with_args (&argc, &argv, "", entries, PACKAGE, &error))
+    if(!gtk_init_with_args (&argc, &argv, NULL, entries, PACKAGE, &error))
     {
         if (G_LIKELY (error))
         {
@@ -253,6 +253,7 @@ main (gint argc, gchar **argv)
         {
             /* Get the dialog widget */
             dialog = gtk_builder_get_object (builder, "dialog");
+            gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_NORMAL);
 
             g_signal_connect (dialog, "response",
                 G_CALLBACK (accessibility_settings_dialog_response), NULL);
