@@ -133,9 +133,10 @@ static void                      xfce_keyboard_settings_reset_button_clicked  (X
 
 #ifdef HAVE_LIBXKLAVIER
 
-static gboolean                  xfce_keyboard_settings_update_sensitive      (GtkToggleButton           *toggle,
+static gboolean                  xfce_keyboard_settings_update_sensitive      (GtkSwitch                 *widget,
                                                                                XfceKeyboardSettings      *settings);
-static void                      xfce_keyboard_settings_system_default_cb     (GtkToggleButton           *toggle,
+static void                      xfce_keyboard_settings_system_default_cb     (GtkSwitch                 *widget,
+                                                                               gboolean                   state,
                                                                                XfceKeyboardSettings      *settings);
 static void                      xfce_keyboard_settings_set_layout            (XfceKeyboardSettings      *settings);
 static void                      xfce_keyboard_settings_init_layout           (XfceKeyboardSettings      *settings);
@@ -342,7 +343,7 @@ xfce_keyboard_settings_constructed (GObject *object)
   GObject              *xkb_numlock;
   GObject              *button;
 #ifdef HAVE_LIBXKLAVIER
-  GObject              *xkb_use_system_default_checkbutton;
+  GObject              *xkb_use_system_default_switch;
   GObject              *xkb_tab_layout_vbox;
   GObject              *xkb_layout_view;
   GObject              *xkb_layout_add_button;
@@ -351,6 +352,7 @@ xfce_keyboard_settings_constructed (GObject *object)
   GObject              *xkb_layout_up_button;
   GObject              *xkb_layout_down_button;
 #endif /* HAVE_LIBXKLAVIER */
+  gboolean              xkb_disable_setting;
 
   /* XKB settings */
   xkb_key_repeat_check = gtk_builder_get_object (GTK_BUILDER (settings), "xkb_key_repeat_check");
@@ -390,16 +392,21 @@ xfce_keyboard_settings_constructed (GObject *object)
   /* Create list store for keyboard shortcuts */
   list_store = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_STRING);
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list_store), COMMAND_COLUMN, GTK_SORT_ASCENDING);
+  gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (kbd_shortcuts_view), COMMAND_COLUMN);
   gtk_tree_view_set_model (GTK_TREE_VIEW (kbd_shortcuts_view), GTK_TREE_MODEL (list_store));
 
   /* Create command column */
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("Command"), renderer, "text", COMMAND_COLUMN, NULL);
+  g_object_set (column, "expand", TRUE, "resizable", TRUE, NULL);
+  g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+  gtk_tree_view_column_set_sort_column_id (column, COMMAND_COLUMN);
   gtk_tree_view_append_column (GTK_TREE_VIEW (kbd_shortcuts_view), column);
 
   /* Create shortcut column */
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("Shortcut"), renderer, "text", SHORTCUT_LABEL_COLUMN, NULL);
+  gtk_tree_view_column_set_sort_column_id (column, SHORTCUT_LABEL_COLUMN);
   gtk_tree_view_append_column (GTK_TREE_VIEW (kbd_shortcuts_view), column);
 
   /* Connect to add button */
@@ -441,14 +448,16 @@ xfce_keyboard_settings_constructed (GObject *object)
   gtk_widget_show (GTK_WIDGET (xkb_tab_layout_vbox));
 
   /* Use system defaults, i.e., disable options */
-  xkb_use_system_default_checkbutton = gtk_builder_get_object (GTK_BUILDER (settings), "xkb_use_system_default_checkbutton");
+  xkb_use_system_default_switch = gtk_builder_get_object (GTK_BUILDER (settings), "xkb_use_system_default_switch");
   xfconf_g_property_bind (settings->priv->keyboard_layout_channel, "/Default/XkbDisable", G_TYPE_BOOLEAN,
-                             (GObject *) xkb_use_system_default_checkbutton, "active");
-  xfce_keyboard_settings_update_sensitive (GTK_TOGGLE_BUTTON (xkb_use_system_default_checkbutton), settings);
-  g_signal_connect (G_OBJECT (xkb_use_system_default_checkbutton),
-                    "toggled",
+                          (GObject *) xkb_use_system_default_switch, "active");
+  g_signal_connect (G_OBJECT (xkb_use_system_default_switch),
+                    "state-set",
                     G_CALLBACK (xfce_keyboard_settings_system_default_cb),
                     settings);
+  xkb_disable_setting = xfconf_channel_get_bool (settings->priv->keyboard_layout_channel, "/Default/XkbDisable", TRUE);
+  gtk_switch_set_state (GTK_SWITCH (xkb_use_system_default_switch), xkb_disable_setting);
+  xfce_keyboard_settings_update_sensitive (GTK_SWITCH (xkb_use_system_default_switch), settings);
 
   /* Keyboard model combo */
   xfce_keyboard_settings_layouts_combo_populate (settings,
@@ -1286,7 +1295,7 @@ xfce_keyboard_settings_xkb_description (XklConfigItem *config_item)
 
 
 static gboolean
-xfce_keyboard_settings_update_sensitive (GtkToggleButton *toggle, XfceKeyboardSettings *settings)
+xfce_keyboard_settings_update_sensitive (GtkSwitch *widget, XfceKeyboardSettings *settings)
 {
   GObject  *xkb_model_frame;
   GObject  *xkb_layout_frame;
@@ -1296,7 +1305,7 @@ xfce_keyboard_settings_update_sensitive (GtkToggleButton *toggle, XfceKeyboardSe
 
   g_return_val_if_fail (XFCE_IS_KEYBOARD_SETTINGS (settings), FALSE);
 
-  active = gtk_toggle_button_get_active (toggle);
+  active = gtk_switch_get_active (widget);
   xkb_model_frame = gtk_builder_get_object (GTK_BUILDER (settings), "xkb_model_frame");
   xkb_layout_frame = gtk_builder_get_object (GTK_BUILDER (settings), "xkb_layout_frame");
   xkb_grpkey_frame = gtk_builder_get_object (GTK_BUILDER (settings), "xkb_grpkey_frame");
@@ -1313,14 +1322,14 @@ xfce_keyboard_settings_update_sensitive (GtkToggleButton *toggle, XfceKeyboardSe
 
 
 static void
-xfce_keyboard_settings_system_default_cb (GtkToggleButton *toggle, XfceKeyboardSettings *settings)
+xfce_keyboard_settings_system_default_cb (GtkSwitch *widget, gboolean state, XfceKeyboardSettings *settings)
 {
   GtkWidget *warning_dialog;
   gboolean   use_system_defaults;
 
   g_return_if_fail (XFCE_IS_KEYBOARD_SETTINGS (settings));
 
-  use_system_defaults = xfce_keyboard_settings_update_sensitive (toggle, settings);
+  use_system_defaults = xfce_keyboard_settings_update_sensitive (widget, settings);
   if (use_system_defaults)
     {
       warning_dialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
