@@ -34,6 +34,8 @@
 #include <xfsettingsd/pointers-defines.h>
 #ifdef HAVE_XCURSOR
 #include <X11/Xcursor/Xcursor.h>
+
+#include <gio/gio.h>
 #endif /* !HAVE_XCURSOR */
 
 #ifdef HAVE_LIBINPUT
@@ -87,6 +89,8 @@ static GOptionEntry option_entries[] =
 };
 
 #ifdef HAVE_XCURSOR
+static const gchar *gsettings_category_gnome_interface = "org.gnome.desktop.interface";
+
 /* icon names for the preview widget */
 static const gchar *preview_names[] = {
     "left_ptr",            "left_ptr_watch",    "watch",             "hand2",
@@ -336,6 +340,7 @@ mouse_settings_themes_selection_changed (GtkTreeSelection *selection,
     gboolean      has_selection;
     gchar        *path, *name;
     GObject      *image;
+    g_autoptr(GSettings) gsettings = NULL;
 
     has_selection = gtk_tree_selection_get_selected (selection, &model, &iter);
     if (G_LIKELY (has_selection))
@@ -350,8 +355,17 @@ mouse_settings_themes_selection_changed (GtkTreeSelection *selection,
 
         /* write configuration (not during a lock) */
         if (locked == 0)
+        {
             xfconf_channel_set_string (xsettings_channel, "/Gtk/CursorThemeName", name);
 
+            /* Keep gsettings in sync */
+            gsettings = g_settings_new (gsettings_category_gnome_interface);
+            if (gsettings)
+            {
+                g_settings_set_string (gsettings, "cursor-theme", name);
+            }
+        }
+
         /* cleanup */
         g_free (path);
         g_free (name);
